.. Copyright © SixtyFPS GmbH <info@slint.dev>
.. SPDX-License-Identifier: MIT

Builtins
========

.. toctree::
   :hidden:
   :maxdepth: 4
   :caption: Builtins

   callbacks.md
   elements.md
   enums.md
   functions.md
   globals.md
   namespaces.md
   structs.md
